@@ -15,8 +15,8 @@
 namespace KSysGuard
 {
 class CGroup;
-
 class CGroupDataModelPrivate;
+class Process;
 
 /**
  * @brief The CGroupDataModel class is a list model of all cgroups from a given root
@@ -114,7 +114,10 @@ Q_SIGNALS:
     void availableChanged();
 
 protected:
-    virtual bool filterAcceptsCGroup(const QString &id);
+    virtual bool filterAcceptsCGroup(CGroup *cgroup);
+    virtual void cgroupAdded(CGroup *cgroup);
+    virtual void cgroupRemoved(CGroup *cgroup);
+    virtual QList<Process *> processesFor(CGroup *cgroup) const;
 
 private:
     QScopedPointer<CGroupDataModelPrivate> d;
